@@ -1,7 +1,7 @@
 """An abstract base class to define the interface for all units."""
 
 from units.compatibility import compatible
-from units.exception import IncompatibleUnitsException
+from units.exception import IncompatibleUnitsError
 from units.quantity import Quantity
 
 class AbstractUnit(object):
@@ -12,13 +12,15 @@ class AbstractUnit(object):
         
     def __call__(self, quantity):
         """Overload the function call operator to convert units."""
-        if compatible(self, quantity.unit):
+        if not hasattr(quantity, 'unit'):
+            return Quantity(quantity, self)
+        elif compatible(self, quantity.unit):
             return Quantity(quantity.num * 
                             quantity.unit.squeeze() / 
                             self.squeeze(), 
                             self)
         else:
-            raise IncompatibleUnitsException()
+            raise IncompatibleUnitsError()
 
     def canonical(self):
         """Return an immutable, comparable derivative of this unit"""
