@@ -126,7 +126,10 @@ class Quantity(object):
         return Quantity(self.num ** exponent, self.unit ** exponent)
             
     def __str__(self):
-        return str(self.num) + ' ' + str(self.unit)
+        if self.unit.str_includes_multiplier():
+            return str(self.num) + ' ' + str(self.unit)
+        else:
+            return str(self.num * self.unit.squeeze()) + ' ' + str(self.unit)
 
     def __repr__(self):
         return ("Quantity(" + 
